@@ -100,7 +100,7 @@ class ObjectSegmentation(QWidget):
         #feature_selection_button = QPushButton("Select features")
         #training_widget.layout().addWidget(feature_selection_button)
 
-        self.feature_selector = FeatureSelector(PredefinedFeatureSet.small_dog_log.value)
+        self.feature_selector = FeatureSelector(PredefinedFeatureSet.v070.value)
         collabsible.addWidget(self.feature_selector)
         collabsible.setDuration(0)
         set_border(collabsible)
@@ -120,7 +120,7 @@ class ObjectSegmentation(QWidget):
         num_trees_spinner.setMinimum(1)
         num_trees_spinner.setMaximum(1000)
         num_trees_spinner.setValue(10)
-        num_max_depth_spinner.setToolTip("The more image channels and features you selected, the more trees should be used to retrieve a reliable and robust classifier. The more trees, the longer processing will take.")
+        num_trees_spinner.setToolTip("The more image channels and features you selected, the more trees should be used to retrieve a reliable and robust classifier. The more trees, the longer processing will take.")
 
         # Max Depth / Number of ensembles
         temp = QWidget()
@@ -135,6 +135,11 @@ class ObjectSegmentation(QWidget):
         self.label_memory_consumption.setToolTip("Try to keep estimated memory consumption low. This will also speed up computation.")
         training_widget.layout().addWidget(self.label_memory_consumption)
 
+        # show statistics checkbox
+        show_classifier_statistics_checkbox = QCheckBox("Show classifier statistics")
+        show_classifier_statistics_checkbox.setChecked(False)
+        training_widget.layout().addWidget(show_classifier_statistics_checkbox)
+
         # Train button
         button = QPushButton("Train")
         def train_clicked(*arg, **kwargs):
@@ -153,7 +158,8 @@ class ObjectSegmentation(QWidget):
                 self.feature_selector.getFeatures(),
                 num_max_depth_spinner.value(),
                 num_trees_spinner.value(),
-                str(filename_edit.value.absolute()).replace("\\", "/").replace("//", "/")
+                str(filename_edit.value.absolute()).replace("\\", "/").replace("//", "/"),
+                show_classifier_statistics_checkbox.isChecked(),
             )
         button.clicked.connect(train_clicked)
         training_widget.layout().addWidget(button)
@@ -161,15 +167,6 @@ class ObjectSegmentation(QWidget):
         verticalSpacer = QSpacerItem(20, 40, QSizePolicy.Minimum, QSizePolicy.Expanding)
         training_widget.layout().addItem(verticalSpacer)
 
-        # ----------------------------------------------------------
-        # Model statistics
-
-        self._model_statistics_table = QTableWidget()
-
-        model_statistics_widget = QWidget()
-        model_statistics_widget.setLayout(QVBoxLayout())
-        model_statistics_widget.layout().addWidget(self._model_statistics_table)
-
         # ----------------------------------------------------------
         # Prediction
         prediction_widget = QWidget()
@@ -207,7 +204,6 @@ class ObjectSegmentation(QWidget):
         # Training / Prediction tabs
         tabs = QTabWidget()
         tabs.addTab(training_widget, "Training")
-        tabs.addTab(model_statistics_widget, "Model statistics")
         tabs.addTab(prediction_widget, "Application / Prediction")
 
         self.layout().addWidget(tabs)
@@ -235,7 +231,16 @@ class ObjectSegmentation(QWidget):
         self.timer.start()
 
 
-    def train(self, images, annotation, object_annotation_value, feature_definition, num_max_depth, num_trees, filename):
+    def train(self,
+              images,
+              annotation,
+              object_annotation_value,
+              feature_definition,
+              num_max_depth,
+              num_trees,
+              filename,
+              show_classifier_statistics,
+    ):
         print("train " + str(self.classifier_class.__name__))
         print("num images", len(images))
         print("object annotation value", object_annotation_value)
@@ -256,30 +261,33 @@ class ObjectSegmentation(QWidget):
             images = images[0]
 
         apoc.erase_classifier(filename)
-        clf = self.classifier_class(
+        classifier = self.classifier_class(
             opencl_filename=filename,
             num_ensembles=num_trees,
             max_depth=num_max_depth)
 
         if self.classifier_class == ObjectSegmenter:
-            clf.positive_class_identifier = object_annotation_value
+            classifier.positive_class_identifier = object_annotation_value
         elif self.classifier_class == ProbabilityMapper:
-            clf.output_probability_of_class = object_annotation_value
+            classifier.output_probability_of_class = object_annotation_value
 
         print("annotation shape", annotation.shape)
 
-        clf.train(feature_definition, annotation, images)
+        classifier.train(feature_definition, annotation, images)
 
         print("Training done. Applying model...")
 
-        result = np.asarray(clf.predict(features=feature_definition, image=images))
+        result = np.asarray(classifier.predict(features=feature_definition, image=images))
 
         print("Applying / prediction done.")
 
         short_filename = filename.split("/")[-1]
         self._add_to_viewer("Result of " + short_filename, result)
 
-        update_model_analysis(self._model_statistics_table, clf)
+        if show_classifier_statistics and self.viewer is not None:
+            table = QTableWidget()
+            update_model_analysis(table, classifier)
+            self.viewer.window.add_dock_widget(table)
 
     def _add_to_viewer(self, name, data):
         try:
@@ -372,7 +380,6 @@ class ObjectSegmentation(QWidget):
 
     def update_image_list(self):
         selected_images = self.get_selected_images()
-        print("selected images was:", selected_images)
 
         self._available_images = []
         self.image_list.clear()
@@ -388,8 +395,7 @@ class ObjectSegmentation(QWidget):
                     item.setSelected(True)
 
         selected_images = self.get_selected_images()
-        print("selected images is:", selected_images)
-
+        
     def get_selected_images(self):
         images = []
         if not hasattr(self, "_available_images"):
@@ -425,26 +431,30 @@ class ObjectSegmentation(QWidget):
 
 def update_model_analysis(statistics_table, classifier):
     table, _ = classifier.statistics()
-
-    statistics_table.clear()
     try:
         statistics_table.setColumnCount(len(next(iter(table.values()))))
         statistics_table.setRowCount(len(table))
     except StopIteration:
         pass
+    update_table_gui(statistics_table, table)
+
+def update_table_gui(statistics_table, table, minimum_value=0.0, maximum_value=1.0):
+    statistics_table.clear()
+
 
     for i, column in enumerate(table.keys()):
-        statistics_table.setVerticalHeaderItem(i, QTableWidgetItem(column))
+        statistics_table.setVerticalHeaderItem(i, QTableWidgetItem(str(i + 1) + " " + column))
 
         for j, value in enumerate(table.get(column)):
             item = QTableWidgetItem("{:.3f}".format(value))
             if not np.isnan(value):
                 brush = QBrush()
-                rel_value = value / np.max([table[key][j] for key in table.keys()])
+                rel_value = (value - minimum_value) / (maximum_value - minimum_value)
                 brush.setColor(QColor(int((1.0 - rel_value) * 255), int(rel_value * 255), int((1.0 - rel_value) * 255), 255 ))
                 item.setBackground(brush.color())
                 item.setForeground(QColor(0,0,0,255))
             statistics_table.setItem(i, j, item)
+        statistics_table.setColumnWidth(i, 40)
 
 
 
@@ -533,7 +543,8 @@ class FeatureSelector(QWidget):
 def napari_experimental_provide_dock_widget():
     # you can return either a single widget, or a sequence of widgets
     from ._function import Train_object_classifier
-    return [ObjectSegmentation, SemanticSegmentation, Train_object_classifier]
+    from ._custom_table_row_classifier import CustomObjectClassifierWidget
+    return [ObjectSegmentation, SemanticSegmentation, Train_object_classifier, CustomObjectClassifierWidget]
 
 
 def set_border(widget:QWidget, spacing=2, margin=0):
