@@ -49,7 +49,8 @@ def test_pixel_training_and_prediction(make_napari_viewer):
             segmenter.feature_selector.getFeatures(),
             2,
             10,
-            classifier_filename
+            classifier_filename,
+            False
         )
 
         segmenter.predict(
@@ -96,3 +97,13 @@ if __name__ == "__main__":
     test_object_training_and_prediction(napari.Viewer)
     test_feature_selector()
     test_pixel_training_and_prediction(napari.Viewer)
+
+def test_custom_object_classifier(make_napari_viewer):
+    viewer = make_napari_viewer()
+
+    from napari_accelerated_pixel_and_object_classification._custom_table_row_classifier import CustomObjectClassifierWidget
+
+    classifier = CustomObjectClassifierWidget(viewer)
+
+    viewer.window.add_dock_widget(classifier)
+    
\ No newline at end of file
